@@ -114,6 +114,7 @@ OC.L10N.register(
     "Deleted user (%s)" : "Implijour dilamet (%s)",
     "Dismiss notification" : "Arrest ar gemenadennoù",
     "Accept" : "Asantiñ",
+    "Notification" : "Kemennadenn",
     "{user} in {call}" : "{user} e {call}",
     "Deleted user in {call}" : "Implijer dilamet e {call}",
     "{guest} (guest) in {call}" : "{guest} (kouviad) e {call}",
@@ -321,7 +322,6 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Saint-Martin (Antilhez)",
     "Madagascar" : "Madagaskar",
     "Marshall Islands" : "Inizi Marshall",
-    "Macedonia, the former Yugoslav Republic of" : "Makedonia an Norzh",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongolia",
@@ -560,6 +560,7 @@ OC.L10N.register(
     "More information" : "Muioc'h a ditouroù",
     "Delete" : "Dilemel",
     "Notifications" : "Kemennadennoù",
+    "Join" : "Kejañ",
     "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
     "Create conversation" : "Krouiñ un diviz",
     "Log in" : "Kennaskañ",
@@ -580,6 +581,11 @@ OC.L10N.register(
     "No camera available" : "Kamera ebet kavet",
     "No audio" : "Audio ebet",
     "No camera" : "Kamera ebet",
+    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
+    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
+    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
+    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
+    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Upload" : "Pellkas",
     "Files" : "Restroù",
@@ -603,7 +609,6 @@ OC.L10N.register(
     "Add more files" : "Ouzhpennañ muioc'h a restroù",
     "Send" : "Kas",
     "Settings" : "Arventennoù",
-    "Join" : "Kejañ",
     "moderator" : "habaskaer",
     "guest" : "kouviad",
     "Remove participant" : "Disachañ an den",
@@ -624,13 +629,7 @@ OC.L10N.register(
     "Link to a conversation" : "Liamm d'an diviz",
     "Search conversations or users" : "Klask divizoù ha implijourienn",
     "Select conversation" : "Choaz un diviz",
-    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
-    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
-    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
-    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
-    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
     "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
-    "Choose devices" : "Choazit un ardivink",
     "Attachments folder" : "Teuliad stag",
     "Select location for attachments" : "Choazit ul lec'h evit stagañ",
     "Privacy" : "Prevezder",
@@ -663,6 +662,7 @@ OC.L10N.register(
     "Stop screensharing" : "Echuañ ar rannadenn skramm",
     "Grid view" : "Diskwell ar roued",
     "Mute others" : "Lakaat ar re all mut",
+    "Keep" : "Mirout",
     "Submit" : "Kinnig",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
@@ -681,11 +681,11 @@ OC.L10N.register(
     "Group" : "Stollad",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
     "Leave this page" : "Kuitaat ar bajenn",
     "Join here" : "Kejañ amañ",
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
+    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
     "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
     "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
@@ -719,6 +719,7 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
     "Copy conversation link" : "Eilañ al liamm diviz",
     "Close" : "Serriñ",
+    "Choose devices" : "Choazit un ardivink",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
     "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
