@@ -721,7 +721,6 @@ OC.L10N.register(
     "Conversation settings" : "Keskustelun asetukset",
     "Basic Info" : "Perustiedot",
     "Personal" : "Henkilökohtainen",
-    "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
     "Breakout Rooms" : "Pienryhmätilat",
     "Matterbridge" : "Matterbridge",
     "Bots" : "Botit",
@@ -853,8 +852,12 @@ OC.L10N.register(
     "Backgrounds" : "Taustakuvat",
     "No audio" : "Ei ääntä",
     "No camera" : "Ei kameraa",
+    "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
+    "Access to microphone is only possible with HTTPS" : "Mikrofonin käyttäminen on mahdollista vain HTTPS-yhteydellä",
+    "Access to microphone was denied" : "Pääsy mikrofoniin estettiin",
+    "Error while accessing microphone" : "Virhe yrittäessä käyttää mikrofonia",
+    "Access to camera is only possible with HTTPS" : "Kameran käyttäminen on mahdollista vain HTTPS-yhteydellä",
     "Media settings" : "Media-asetukset",
-    "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
     "The call is being recorded." : "Tämä puhelu tallennetaan.",
     "Call without notification" : "Puhelu ilman ilmoitusta",
     "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
@@ -1092,20 +1095,15 @@ OC.L10N.register(
     "Number length is not valid" : "Numeron pituus on virheellinen",
     "Number is not valid" : "Numero ei ole kelvollinen",
     "Phone numbers" : "Puhelinnumerot",
+    "Display name: {name}" : "Näyttönimi: {name}",
     "Edit display name" : "Muokkaa näyttönimeä",
     "Save name" : "Tallenna nimi",
-    "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
-    "Access to microphone is only possible with HTTPS" : "Mikrofonin käyttäminen on mahdollista vain HTTPS-yhteydellä",
-    "Access to microphone was denied" : "Pääsy mikrofoniin estettiin",
-    "Error while accessing microphone" : "Virhe yrittäessä käyttää mikrofonia",
-    "Access to camera is only possible with HTTPS" : "Kameran käyttäminen on mahdollista vain HTTPS-yhteydellä",
     "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
     "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
     "Sounds setting saved" : "Ääniasetukset tallennettu",
     "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
-    "Choose devices" : "Valitse laitteet",
     "Attachments folder" : "Liitteiden kansio",
     "Browse …" : "Selaa…",
     "Select location for attachments" : "Valitse sijainti liitteille",
@@ -1186,7 +1184,6 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Liityit keskusteluun toisessa ikkunassa tai toisella laitteella. Tämä ei ole tällä hetkellä tuettua Nextcloud Talkissa, joten tämä istunto suljettiin.",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
-    "Display name: {name}" : "Näyttönimi: {name}",
     "Nextcloud URL" : "Nextcloudin URL-osoite",
     "Nextcloud user" : "Nextcloud-käyttäjä",
     "User password" : "Käyttäjän salasana",
@@ -1250,7 +1247,11 @@ OC.L10N.register(
     "(edited by a deleted user)" : "(muokattu poistetun käyttäjän toimesta)",
     "Leave this page" : "Poistu tältä sivulta",
     "Join here" : "Liity tähän",
+    "Post to a conversation" : "Lähetä keskusteluun",
+    "Post to conversation" : "Lähetä keskusteluun",
     "The recording failed. Please contact your administrator." : "Tallennus epäonnistui. Ole yhteydessä ylläpitoon.",
+    "Share to a conversation" : "Jaa keskusteluun",
+    "Share to conversation" : "Jaa keskusteluun",
     "Search in conversation: {conversation}" : "Etsi keskustelusta: {conversation}",
     "Error while clearing conversation history" : "Virhe keskusteluhistoriaa siivotessa",
     "Error occurred while allowing guests" : "Virhe vieraita salliessa",
@@ -1309,10 +1310,13 @@ OC.L10N.register(
     "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
     "Join »%s«" : "Liity »%s«",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
+    "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
     "Copy conversation link" : "Kopioi keskustelulinkki",
     "Filter unread mentions" : "Suodata lukemattomat maininnat",
     "Filter unread messages" : "Suodata lukemattomat viestit",
+    "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
     "Close" : "Sulje",
+    "Choose devices" : "Valitse laitteet",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
     "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
     "Failed to join the conversation. Try to reload the page." : "Liittyminen keskusteluun epäonnistui. Päivitä sivu.",
