@@ -676,7 +676,6 @@ OC.L10N.register(
     "Meeting" : "Sastanak",
     "Conversation settings" : "Postavke razgovora",
     "Personal" : "Osobno",
-    "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona opasnosti",
     "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
@@ -763,6 +762,11 @@ OC.L10N.register(
     "Devices" : "Uređaji",
     "No audio" : "Nema zvuka",
     "No camera" : "Nema kamere",
+    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
+    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
+    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
+    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
+    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
     "Invalid path selected" : "Odabran nevažeći put",
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
@@ -881,11 +885,6 @@ OC.L10N.register(
     "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
     "Search conversations or users" : "Pretraži razgovore ili korisnike",
     "Select conversation" : "Odaberi razgovor",
-    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
-    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
-    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
-    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
-    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
     "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
     "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
     "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
@@ -893,7 +892,6 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
     "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
-    "Choose devices" : "Odaberi uređaje",
     "Attachments folder" : "Mapa s privicima",
     "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Appearance" : "Izgled",
@@ -1019,6 +1017,8 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
     "Leave this page" : "Napusti ovu stranicu",
     "Join here" : "Pridruži se ovdje",
+    "Post to a conversation" : "Objavite u razgovoru",
+    "Post to conversation" : "Objavi u razgovoru",
     "Error while clearing conversation history" : "Pogreška pri brisanju povijesti razgovora",
     "Error occurred while allowing guests" : "Došlo je do pogreške pri omogućavanju pristupa gostima",
     "Error occurred while disallowing guests" : "Došlo je do pogreške pri onemogućavanju pristupa gostima",
@@ -1070,8 +1070,10 @@ OC.L10N.register(
     "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
     "Join »%s«" : "Pridruži se »%s«",
     "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
+    "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
     "Copy conversation link" : "Kopiraj poveznicu za razgovor",
     "Close" : "Zatvori",
+    "Choose devices" : "Odaberi uređaje",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
     "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
