@@ -34,6 +34,8 @@ OC.L10N.register(
     "Dismiss notification" : "Abaikan notifikasi",
     "Accept" : "Terima",
     "Decline" : "Tolak",
+    "New message" : "Pesan baru",
+    "Notification" : "Notifikasi",
     "error" : "galat",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Uni Emirat Arab",
@@ -277,7 +279,6 @@ OC.L10N.register(
     "Back" : "Kembali",
     "Cancel" : "Membatalkan",
     "Loading …" : "Memuat …",
-    "No upcoming events" : "Tdak ada acara mendatang",
     "Calendar" : "Kalender",
     "Attendees" : "Peserta",
     "Save" : "Simpan",
@@ -295,18 +296,20 @@ OC.L10N.register(
     "Enable" : "Aktifkan",
     "Choose" : "Pilih",
     "Restricted" : "Terbatas",
-    "Personal" : "Pribadi",
     "Meeting" : "Rapat",
+    "Personal" : "Pribadi",
     "Password protection" : "Password protection",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
     "Notifications" : "Pemberitahuan",
+    "Join" : "Gabung",
     "Create conversation" : "Buat percakapan",
     "Log in" : "Masuk",
     "Mark as read" : "tandai sudah dibaca",
     "Mark as unread" : "Tandai belum dibaca",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
+    "Unread messages" : "Pesan belum dibaca",
     "Clear filter" : "Bersihkan filter",
     "Users" : "Pengguna",
     "Groups" : "Grup",
@@ -316,7 +319,6 @@ OC.L10N.register(
     "Blur" : "Kabur",
     "Upload" : "Unggah",
     "Files" : "Berkas",
-    "Unread messages" : "Pesan belum dibaca",
     "Reply" : "Balas",
     "Translate" : "Terjemahkan",
     "Dismiss" : "Batal",
@@ -330,7 +332,6 @@ OC.L10N.register(
     "Blank" : "Kosong",
     "Send" : "Kirim",
     "Settings" : "Setelan",
-    "Join" : "Gabung",
     "guest" : "pengunjung",
     "Remove" : "Hapus",
     "Add users or groups" : "Add users or groups",
@@ -342,7 +343,6 @@ OC.L10N.register(
     "Load more results" : "Muat lebih banyak hasil",
     "Projects" : "Proyek",
     "Search conversations or users" : "Cari percakapan atau pengguna",
-    "Choose devices" : "Pilih perangkat",
     "Attachments folder" : "Folder lampiran",
     "Appearance" : "Tampilan",
     "Privacy" : "Privasi",
@@ -350,6 +350,7 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Search" : "Cari",
     "Grid view" : "Tampilan kotak",
+    "Keep" : "Simpan",
     "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
     "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
     "User" : "Pengguna",
@@ -377,6 +378,7 @@ OC.L10N.register(
     "Notes" : "Catatan",
     "Reports" : "Laporan",
     "Call summary - {title}" : "Ringkasan panggilan - {judul}",
-    "Close" : "Tutup"
+    "Close" : "Tutup",
+    "Choose devices" : "Pilih perangkat"
 },
 "nplurals=1; plural=0;");
