@@ -750,7 +750,6 @@ OC.L10N.register(
     "Conversation settings" : "Impostazioni conversazione",
     "Basic Info" : "Informazioni di base",
     "Personal" : "Personale",
-    "Always show the device preview screen before joining a call in this conversation." : "Mostra sempre la schermata di anteprima del dispositivo prima di partecipare a una chiamata in questa conversazione.",
     "Moderation" : "Moderazione",
     "Matterbridge" : "Matterbridge",
     "Bots" : "Bot",
@@ -852,6 +851,11 @@ OC.L10N.register(
     "Devices" : "Dispositivi",
     "No audio" : "Nessun audio",
     "No camera" : "Nessuna fotocamera",
+    "Calls are not supported in your browser" : "Le chiamate non sono supportate dal tuo browser",
+    "Access to microphone is only possible with HTTPS" : "L'accesso a microfono è possibile solo con HTTPS",
+    "Access to microphone was denied" : "L'accesso al microfono è stato negato",
+    "Error while accessing microphone" : "Errore durante l'accesso al microfono",
+    "Access to camera is only possible with HTTPS" : "L'accesso alla fotocamera è possibile solo con HTTPS",
     "Call without notification" : "Chiama senza notifica",
     "Invalid path selected" : "Percorso selezionato non valido",
     "Blur" : "Sfocatura",
@@ -1003,11 +1007,6 @@ OC.L10N.register(
     "Search conversations or users" : "Cerca conversazioni o utenti",
     "Select conversation" : "Seleziona conversazione",
     "Edit display name" : "Modifica nome visualizzato",
-    "Calls are not supported in your browser" : "Le chiamate non sono supportate dal tuo browser",
-    "Access to microphone is only possible with HTTPS" : "L'accesso a microfono è possibile solo con HTTPS",
-    "Access to microphone was denied" : "L'accesso al microfono è stato negato",
-    "Error while accessing microphone" : "Errore durante l'accesso al microfono",
-    "Access to camera is only possible with HTTPS" : "L'accesso alla fotocamera è possibile solo con HTTPS",
     "Choose the folder in which attachments should be saved." : "Scegli la cartella in cui salvare gli allegati.",
     "Error while setting attachment folder" : "Errore durante l'impostazione della cartella degli allegati",
     "Your privacy setting has been saved" : "Le tue impostazioni di riservatezza sono state salvate",
@@ -1015,7 +1014,6 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Errore nel salvare le impostazioni dei suoni ",
     "Sounds setting saved" : "Impostazione dei suoni salvata",
     "Error while saving sounds setting" : "Errore durante il salvataggio dell'impostazione dei suoni",
-    "Choose devices" : "Scegli i dispositivi",
     "Attachments folder" : "Cartella degli allegati",
     "Browse …" : "Sfoglia ...",
     "Select location for attachments" : "Seleziona la posizione per gli allegati",
@@ -1161,6 +1159,8 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
     "Leave this page" : "Abbandona questa pagina",
     "Join here" : "Unisciti qui",
+    "Post to a conversation" : "Pubblica in una conversazione",
+    "Post to conversation" : "Pubblica in conversazione",
     "Error while clearing conversation history" : "Errore durante la cancellazione della cronologia della conversazione",
     "Error occurred while allowing guests" : "Si è verificato un errore durante l'autorizzazione degli ospiti",
     "Error occurred while disallowing guests" : "Si è verificato un errore durante la disabilitazione degli ospiti",
@@ -1216,8 +1216,10 @@ OC.L10N.register(
     "Click the button below to join." : "Fai clic sul pulsante sotto per partecipare.",
     "Join »%s«" : "Unisciti a «%s»",
     "{user} invited you to a private conversation" : "{user} ti ha invitato a una conversazione privata",
+    "Always show the device preview screen before joining a call in this conversation." : "Mostra sempre la schermata di anteprima del dispositivo prima di partecipare a una chiamata in questa conversazione.",
     "Copy conversation link" : "Copia collegamento della conversazione",
     "Close" : "Chiudi",
+    "Choose devices" : "Scegli i dispositivi",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk è stato aggiornato, devi ricaricare la pagina prima di poter iniziare o partecipare a una chiamata.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk è stato aggiornato, ricarica la pagina",
     "An error happened when trying to share your file" : "Si è verificato un errore durante il tentativo di condividere il tuo file",
