@@ -637,7 +637,6 @@ OC.L10N.register(
     "Conversation settings" : "Параметри за разговор",
     "Basic Info" : "Основни информации",
     "Personal" : "Лично",
-    "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
     "Danger zone" : "Опасна зона",
     "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
     "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
@@ -696,6 +695,11 @@ OC.L10N.register(
     "Devices" : "Уреди",
     "No audio" : "Нема аудио",
     "No camera" : "Нема камера",
+    "Calls are not supported in your browser" : "Повици не се поддржани од вашиот прелистувач",
+    "Access to microphone is only possible with HTTPS" : "Пристап до микрофонот е возможен само преку безбедноска врска HTTPS",
+    "Access to microphone was denied" : "Нема пристап до микрофонот",
+    "Error while accessing microphone" : "Грешка при пристап до микрофон",
+    "Access to camera is only possible with HTTPS" : "Пристап до камерата е возможен само преку безбедноска врска HTTPS",
     "Invalid path selected" : "Избрана невалидна патека",
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
@@ -845,11 +849,6 @@ OC.L10N.register(
     "Select conversation" : "Избери разговор",
     "Edit display name" : "Иреди име",
     "Save name" : "Зачувај име",
-    "Calls are not supported in your browser" : "Повици не се поддржани од вашиот прелистувач",
-    "Access to microphone is only possible with HTTPS" : "Пристап до микрофонот е возможен само преку безбедноска врска HTTPS",
-    "Access to microphone was denied" : "Нема пристап до микрофонот",
-    "Error while accessing microphone" : "Грешка при пристап до микрофон",
-    "Access to camera is only possible with HTTPS" : "Пристап до камерата е возможен само преку безбедноска врска HTTPS",
     "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
@@ -857,7 +856,6 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
     "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
-    "Choose devices" : "Избери уреди",
     "Attachments folder" : "Папка со прилози",
     "Select location for attachments" : "Избери локација за прилози",
     "Appearance" : "Изглед",
@@ -963,6 +961,11 @@ OC.L10N.register(
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
     "Leave this page" : "Напушти ја оваа страна",
     "Join here" : "Приклучи се овде",
+    "Post to a conversation" : "Објави во разговор",
+    "Post to conversation" : "Објава во разговор",
+    "An error occurred while posting location to conversation" : "Настана грешка при обид за објава на локација во разговор",
+    "Share to a conversation" : "Сподели во разговор",
+    "Share to conversation" : "Споделено во разговор",
     "Error while clearing conversation history" : "Грешка при чистење на историјата во разговорот",
     "Error occurred while allowing guests" : "Настана грешка при обидот за овозможување на гостите",
     "Error occurred while disallowing guests" : "Настана грешка при обидот за оневозможување на гостите",
@@ -1006,8 +1009,10 @@ OC.L10N.register(
     "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
     "Join »%s«" : "Приклучете се »%s«",
     "{user} invited you to a private conversation" : "{user} те покани на приватен разговор",
+    "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
     "Copy conversation link" : "копирај линк од разговорот",
     "Close" : "Затвори",
+    "Choose devices" : "Избери уреди",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
     "Nextcloud Talk was updated, please reload the page" : "Разговорот е ажуриран, повторно вчитајте ја страната",
     "An error happened when trying to share your file" : "Се случи грешка при обидот за споделување на датотека",
