@@ -663,7 +663,6 @@ OC.L10N.register(
     "Meeting" : "Reünion",
     "Conversation settings" : "Paramètres de conversacion",
     "Personal" : "Personal",
-    "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
@@ -751,6 +750,11 @@ OC.L10N.register(
     "Backgrounds" : "Rèireplans",
     "No audio" : "Cap d’àudio",
     "No camera" : "Cap de camèra",
+    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
+    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
+    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
+    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
+    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
     "Media settings" : "Paramètres dels mèdias",
     "Invalid path selected" : "Camin seleccionat invalid",
     "Upload" : "Cargament",
@@ -903,12 +907,8 @@ OC.L10N.register(
     "Number length is too long" : "La longor del numèro es tròp longa",
     "Number is not valid" : "Lo numèro es pas valid",
     "Phone numbers" : "Numèros de telefòn",
+    "Display name: {name}" : "Nom d’afichatge : {name}",
     "Save name" : "Enregistrar lo nom",
-    "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
-    "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
-    "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
-    "Error while accessing microphone" : "Error pendent l’accès al microfòn",
-    "Access to camera is only possible with HTTPS" : "L’accès a la camèra es sonque possibla amb HTTPS",
     "Choose the folder in which attachments should be saved." : "Causir lo dossièr ont seràn gardadas las pèça juntas.",
     "Error while setting attachment folder" : "Error pendent la definicion del dossièr de pèça junta",
     "Your privacy setting has been saved" : "Paramètre de confidencialitat enregistrat",
@@ -916,7 +916,6 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
-    "Choose devices" : "Causir periferics",
     "Attachments folder" : "Dossièr de pèças-juntas",
     "Browse …" : "Percórrer...",
     "Select location for attachments" : "Causir un emplaçament per las pèças juntas",
@@ -992,7 +991,6 @@ OC.L10N.register(
     "Duplicate session" : "Duplicar la session",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Avètz rejonch la conversacion dins una autra fenèstra o periferic. Aquò es actualament pas pres en cargar per Nextcloud Talk doncas aquesta session es estada tampada.",
     "Join a conversation or start a new one" : "Rejónher una conversacion o ne crear una",
-    "Display name: {name}" : "Nom d’afichatge : {name}",
     "Nextcloud URL" : "URL Nextcloud",
     "Nextcloud user" : "Utilizaire Nextcloud",
     "User password" : "Senhal utilizaire",
@@ -1054,6 +1052,11 @@ OC.L10N.register(
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Leave this page" : "Quitar aquesta pagina",
     "Join here" : "Rejónher aquí",
+    "Post to a conversation" : "Publicar dins una conversacion",
+    "Post to conversation" : "Publicar a la conversacion",
+    "An error occurred while posting location to conversation" : "Error en publicant la localizacion dins la conversacion",
+    "Share to a conversation" : "Partejar dins una conversacion",
+    "Share to conversation" : "Partejar dins una conversacion",
     "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
     "Error occurred while allowing guests" : "Error en autorizant los convidats",
     "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
@@ -1105,8 +1108,10 @@ OC.L10N.register(
     "Click the button below to join." : "Clicatz sul boton per participar.",
     "Join »%s«" : "Rejónher « %s »",
     "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
+    "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Copy conversation link" : "Copiar lo ligam de conversacion",
     "Close" : "Tampar",
+    "Choose devices" : "Causir periferics",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
