@@ -148,6 +148,9 @@ OC.L10N.register(
     "Transcript now available" : "Transcrierea este acum disponibilă",
     "Accept" : "Accept",
     "Decline" : "Refuză",
+    "New message" : "Mesaj nou",
+    "Reminder" : "Memento",
+    "Notification" : "Notificări",
     "{user} reacted with {reaction}" : "{user} a reacționat cu {reaction}",
     "{user} reacted with {reaction} in {call}" : "{user} a reacționat cu {reaction} în {call}",
     "{user} in {call}" : "{user} în {call}",
@@ -488,7 +491,6 @@ OC.L10N.register(
     "Cancel" : "Anulare",
     "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
     "Now" : "Acum",
-    "No upcoming events" : "Niciun eveniment următor",
     "From" : "De la",
     "To" : "Către",
     "Calendar" : "Calendar",
@@ -559,12 +561,11 @@ OC.L10N.register(
     "Restricted" : "Restricționat",
     "Advanced permissions" : "Permisiuni avansate",
     "Edit permissions" : "Editare permisiuni",
+    "Meeting" : "Videoconferință",
     "Conversation settings" : "Configurația conversației",
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
-    "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
     "Moderation" : "Moderare",
-    "Meeting" : "Videoconferință",
     "Do you really want to delete \"{displayName}\"?" : "Sigur ștergeți \"{displayName}\"?",
     "Do you really want to delete all messages in \"{displayName}\"?" : "Sigur ștergeți toate mesajele din \"{displayName}\"?",
     "Error while deleting conversation" : "Eroare la ștergerea conversației",
@@ -600,6 +601,8 @@ OC.L10N.register(
     "More information" : "Mai multe informații",
     "Delete" : "Șterge",
     "Notifications" : "Notificări",
+    "Create a new conversation" : "Creează o nouă conversație",
+    "Unread mentions" : "Menționări necitite",
     "Create conversation" : "Creați o conversație",
     "Enter your name" : "Introduceți numele",
     "Submit name and join" : "Transmite numele și participați",
@@ -617,13 +620,9 @@ OC.L10N.register(
     "You have no unread mentions." : "Nu aveți menționări necitite.",
     "You have no unread messages." : "Nu aveți mesaje necitite.",
     "Conversation list" : "Lista de conversații",
-    "Filter unread mentions" : "Filtrează mențiunile necitite",
-    "Filter unread messages" : "Filtrează mesajele necitite",
     "Clear filters" : "Șterge filtrele",
-    "Create a new conversation" : "Creează o nouă conversație",
     "New personal note" : "Notă personală nouă",
     "Clear filter" : "Șterge filtrul",
-    "Unread mentions" : "Menționări necitite",
     "Talk settings" : "Setări Talk",
     "Users" : "Utilizatori",
     "Groups" : "Grupuri",
@@ -634,6 +633,9 @@ OC.L10N.register(
     "The meeting will start soon" : "Întâlnirea va începe în curând",
     "None" : "Niciuna",
     "Devices" : "Dispozitive",
+    "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
+    "Access to microphone was denied" : "Accesul la microfon a fost respins",
+    "Error while accessing microphone" : "Eroare la accesarea microfonului",
     "Invalid path selected" : "Calea selectată este invalidă",
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
@@ -727,10 +729,8 @@ OC.L10N.register(
     "Select conversation" : "Selectare conversație",
     "Number length is not valid" : "Lungime număr incorectă",
     "Phone numbers" : "Numere de telefon",
+    "Display name: {name}" : "Numele afișat: {name}",
     "Save name" : "Salvează numele",
-    "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
-    "Access to microphone was denied" : "Accesul la microfon a fost respins",
-    "Error while accessing microphone" : "Eroare la accesarea microfonului",
     "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
     "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
     "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
@@ -739,12 +739,11 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Choose devices" : "Selectați dispozitivele",
     "Attachments folder" : "Dosarul pentru atașamente",
     "Browse …" : "Navigare ...",
     "Select location for attachments" : "Selectați locația atașamentelor",
     "Appearance" : "Aspect",
-    "Privacy" : "Confindențialitate",
+    "Privacy" : "Confidențialitate",
     "Share my read-status and show the read-status of others" : "Arată statusul meu de citire și pe al celorlalți",
     "Share my typing-status and show the typing-status of others" : "Arată când tastez eu și ceilalți",
     "Sounds" : "Sunete",
@@ -802,6 +801,7 @@ OC.L10N.register(
     "Mute others" : "Închide microfonul celorlalți",
     "Toggle full screen" : "Comută în ecran complet",
     "Remove participant {name}" : "Elimină participantul {name}",
+    "Keep" : "Păstrare",
     "Select a region" : "Selectează o regiune",
     "Submit" : "Trimite",
     "Search …" : "Caută ...",
@@ -811,7 +811,6 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "Particiăați la o conversație sau creați una nouă!",
     "Duplicate session" : "Sesiune duplicat",
     "Join a conversation or start a new one" : "Participați la o conversație sau începeți una nouă",
-    "Display name: {name}" : "Numele afișat: {name}",
     "Talk conversation" : "Conversație Talk",
     "User" : "Utilizator",
     "Password" : "Parolă",
@@ -843,7 +842,15 @@ OC.L10N.register(
     "An administrator added {user0} and {user1}" : "Un administrator a adăugat pe {user0} și pe {user1}",
     "{actor} added {user0} and {user1}" : "{actor} a adăugat pe {user0} și pe {user1}",
     "You: {lastMessage}" : "Tu: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
+    "Leave this page" : "Părăsește pagina",
+    "Join here" : "Alăturare aici",
     "Deck card has been posted to {conversation}" : "Cardul Deck a fost postat la conversația {conversation}",
+    "An error occurred while posting deck card to conversation" : "Eroare la postarea cardului Deck în conversație",
+    "Post to a conversation" : "Postare într-o conversație",
+    "Post to conversation" : "Postare în conversație",
+    "Share to a conversation" : "Partajare la o conversație",
+    "Share to conversation" : "Partajare la conversație",
     "Error while clearing conversation history" : "Eroare la ștergerea istoricului conversației",
     "Conversation password has been saved" : "Parola conversației a fost salvată",
     "Conversation password has been removed" : "Parola conversație a fost ștearsă",
@@ -856,9 +863,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Eroare la preluarea listei de participanți",
     "Could not send invitation to {actorId}" : "Nu a fost trimisă invitația către {actorId}",
     "Invitations sent" : "Invitațiile au fost trimise",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Încercați să participați la o conversație având o sesiune activă în altă fereastră sau dispozitiv. Acest lucru nu este suportat în prezent în Nextcloud Talk. Ce doriți să faceți?",
-    "Leave this page" : "Părăsește pagina",
-    "Join here" : "Alăturare aici",
     "An error occurred while requesting assistance" : "Eroare la solicitarea de asistență",
     "An error occurred while resetting the request for assistance" : "Eroare la resetarea solicitării de asistență",
     "An error occurred while submitting your vote" : "Eroare la transmiterea votului",
@@ -887,8 +891,12 @@ OC.L10N.register(
     "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
     "Join »%s«" : "Alăturați-vă »%s«",
     "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
+    "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
     "Copy conversation link" : "Copiază linkul conversației",
+    "Filter unread mentions" : "Filtrează mențiunile necitite",
+    "Filter unread messages" : "Filtrează mesajele necitite",
     "Close" : "Închide",
+    "Choose devices" : "Selectați dispozitivele",
     "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
     "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
 },
