@@ -167,6 +167,7 @@ OC.L10N.register(
     "Dismiss notification" : "Iscarta notìfica",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
+    "New message" : "Messàgiu nou",
     "{user} in {call}" : "{user} in {call}",
     "Deleted user in {call}" : "Utente cantzelladu in {call}",
     "{guest} (guest) in {call}" : "{guest} (utèntzia istràngia) in {call}",
@@ -378,7 +379,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "San Martin (parte Frantzesa)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Ìsulas Marshall",
-    "Macedonia, the former Yugoslav Republic of" : "Macedònia",
+    "North Macedonia" : "Macedònia de su Nord",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongòlia",
@@ -601,7 +602,6 @@ OC.L10N.register(
     "Cancel" : "Annulla",
     "Add participant \"{user}\"" : "Agiunghe partetzipante \"{user}\"",
     "Loading …" : "Carrigamentu …",
-    "No upcoming events" : "Perunu eventu abarradu",
     "From" : "Dae",
     "To" : "A",
     "Calendar" : "Calendàriu",
@@ -660,9 +660,9 @@ OC.L10N.register(
     "The file must be a PNG or JPG" : "S'archìviu depet èssere unu PNG o JPG",
     "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni borta chi is permissos sunt modificados in custa setzione, is permissos personalizados assignados in pretzedèntzia a partetzipantes individuales ant a èssere pèrdidos.",
     "Restricted" : "Limitadu",
+    "Meeting" : "Atòbiu",
     "Conversation settings" : "Cunfiguratzione de sa resonada",
     "Personal" : "Personale",
-    "Meeting" : "Atòbiu",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona de perìgulu",
     "Do you really want to delete \"{displayName}\"?" : "A beru boles cantzellare \"{displayName}\"?",
@@ -685,8 +685,6 @@ OC.L10N.register(
     "Save password" : "Sarva sa crae",
     "Resend invitations" : "Torra a imbiare is invitos",
     "Error occurred when opening or limiting the conversation" : "B'at àpidu un'errore aberrende o limitende sa resonada",
-    "Error occurred when restricting the conversation to moderator" : "B'at àpidu un'errore limitende sa resonada a chie moderat",
-    "Error occurred when opening the conversation to everyone" : "B'at àpidu un'errore aberrende sa resonada a totus",
     "Start time has been updated" : "S'ora de cumintzu est istada agiornada",
     "Error occurred while updating start time" : "B'at àpidu un'errore agiornende s'ora de cumintzu",
     "Meeting start time" : "Ora de cumintzu de sa riunione",
@@ -710,11 +708,14 @@ OC.L10N.register(
     "Show Matterbridge log" : "Mustra su registru de Matterbridge",
     "Log content" : "Cuntenutu de is registros",
     "Notifications" : "Notìficas",
+    "Important conversation" : "Tzarrada importante",
     "SIP dial-in is now enabled" : "S'atzessu SIP immoe est ativu",
     "SIP dial-in is now disabled" : "S'atzessu SIP immoe est disativu",
     "Error occurred when enabling SIP dial-in" : "B'at àpidu un'errore ativende s'atzessu SIP",
     "Error occurred when disabling SIP dial-in" : "B'at àpidu un'errore disativende s'atzessu SIP",
+    "Join" : "Intra",
     "Error while creating the conversation" : "Errore creende sa resonada ",
+    "Create a new conversation" : "Crea una resonada noa",
     "Create conversation" : "Crea resonada",
     "Enter your name" : "Inserta•nche su nùmene tuo",
     "Log in" : "Intra",
@@ -729,7 +730,7 @@ OC.L10N.register(
     "No conversations found" : "Peruna resonada agatada",
     "An error occurred while performing the search" : "B'at àpidu un'errore in sa chirca",
     "Conversation list" : "Lista de is resonadas",
-    "Create a new conversation" : "Crea una resonada noa",
+    "Unread messages" : "Messàgios non lèghidos",
     "New personal note" : "Nota personale noa",
     "Clear filter" : "Lìmpia filtru",
     "Talk settings" : "Cunfiguratzione de Talk",
@@ -750,6 +751,11 @@ OC.L10N.register(
     "Devices" : "Dispositivos",
     "No audio" : "Àudiu perunu",
     "No camera" : "Peruna fotocàmera",
+    "Calls are not supported in your browser" : "Is mutidas no sunt suportadas in su navigadore tuo",
+    "Access to microphone is only possible with HTTPS" : "S'atzessu a su micròfonu si podet fàghere isceti cun HTTPS",
+    "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
+    "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
+    "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
     "Media settings" : "Cunfiguratzione de is elementos multimediales",
     "Invalid path selected" : "Percursu seletzionadu non bàlidu",
     "Upload" : "Càrriga",
@@ -761,7 +767,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Su messàgiu non si podet cantzellare ca est tropu betzu",
     "Only normal chat messages can be deleted" : "Si podent cantzellare isceti is messàgios de tzarrada normales",
     "An error occurred while deleting the message" : "B'at àpidu un'errore cantzellende su messàgiu",
-    "Unread messages" : "Messàgios non lèghidos",
     "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
     "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
     "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
@@ -826,7 +831,6 @@ OC.L10N.register(
     "Send" : "Imbia",
     "Settings" : "Cunfiguratzione",
     "Anonymous poll" : "Sondàgiu anònimu",
-    "Join" : "Intra",
     "Disable lobby" : "Disativa intrada",
     "Settings for participant \"{user}\"" : "Cunfiguratzione pro partetzipante \"{user}\"",
     "Participant \"{user}\"" : "Partetzipante \"{user}\"",
@@ -867,11 +871,6 @@ OC.L10N.register(
     "Link to a conversation" : "Collega a una resonada",
     "Search conversations or users" : "Chirca resonadas o utentes",
     "Select conversation" : "Seletziona resonada",
-    "Calls are not supported in your browser" : "Is mutidas no sunt suportadas in su navigadore tuo",
-    "Access to microphone is only possible with HTTPS" : "S'atzessu a su micròfonu si podet fàghere isceti cun HTTPS",
-    "Access to microphone was denied" : "S'atzessu a su micròfonu est istadu negadu",
-    "Error while accessing microphone" : "Errore in s'atzessu a su micròfonu",
-    "Access to camera is only possible with HTTPS" : "S'atzessu a sa càmera si podet fàghere isceti cun HTTPS",
     "Choose the folder in which attachments should be saved." : "Sèbera in cale cartella depent èssere sarvados is alligongiados.",
     "Error while setting attachment folder" : "Errore in sa cunfiguratzione de sa cartella de is alligongiados",
     "Your privacy setting has been saved" : "Sa cunfiguratzione de riservadesa tua est istada sarvada",
@@ -879,7 +878,6 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Non at fatu a sarvare sa cunfiguratzione de is sonos",
     "Sounds setting saved" : "Cunfiguratzione de is sonos sarvada",
     "Error while saving sounds setting" : "Errore sarvende sa cunfiguratzione de is sonos",
-    "Choose devices" : "Sèbera dispositivos",
     "Attachments folder" : "Cartella de alligongiados",
     "Select location for attachments" : "Seletziona sa positzione pro is alligongiados",
     "Appearance" : "Aspetu",
@@ -935,6 +933,7 @@ OC.L10N.register(
     "Lower hand" : "Bàscia sa manu ",
     "Lower hand (R)" : "Bàscia sa manu (R)",
     "Mute others" : "Tira s'àudio a àtere",
+    "Keep" : "Mantene",
     "Select a region" : "Seletziona una regione",
     "Submit" : "Imbia",
     "Message without mention" : "Messàgiu chena mentovu",
@@ -996,9 +995,16 @@ OC.L10N.register(
     "Group" : "Grupu",
     "You: {lastMessage}" : "Tue: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
+    "Leave this page" : "Lassa custa pàgina",
+    "Join here" : "Intra inoghe",
+    "Post to a conversation" : "Pùblica in una resonada",
+    "Post to conversation" : "Pùblica in sa resonada",
     "Error while clearing conversation history" : "Errore limpiende s'istòria de sa resonada",
     "Error occurred while allowing guests" : "B'at àpidu un'errore autorizende is persones invitadas",
     "Error occurred while disallowing guests" : "B'at àpidu un'errore refudende is persones invitadas",
+    "Error occurred when restricting the conversation to moderator" : "B'at àpidu un'errore limitende sa resonada a chie moderat",
+    "Error occurred when opening the conversation to everyone" : "B'at àpidu un'errore aberrende sa resonada a totus",
     "Conversation password has been saved" : "Sa crae de sa resonada est istada sarvada",
     "Conversation password has been removed" : "Sa crae de sa resonada nch'est istada bogada",
     "Error occurred while saving conversation password" : "B'at àpidu un'errore sarvende sa crae de sa resonada",
@@ -1010,9 +1016,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "No at fatu a imbiare s'invitu a {actorId}.",
     "Invitations sent" : "Invitos imbiados",
     "Error occurred when sending invitations" : "B'at àpidu un'errore imbiende is invitos",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ses proende a intrare in una resonada cun una sessione ativa in un'àtera ventana o dispositivu. In custu momentu cust'atzione no est suportada dae Nextcloud Talk. Ite boles fàghere?",
-    "Leave this page" : "Lassa custa pàgina",
-    "Join here" : "Intra inoghe",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Su navigadore chi ses impreende no est suportadu totu dae Nextcloud. Imprea s'ùrtima versione de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Connessione pèrdida cun su serbidore de signalatzione. Proende a torrare a connètere",
     "Establishing signaling connection is taking longer than expected …" : "Sa creatzione de sa connessione de signalatzione est istentende prus de su tempus prevìdidu ...",
@@ -1050,6 +1053,7 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
     "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
     "Close" : "Serra",
+    "Choose devices" : "Sèbera dispositivos",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud est istadu agiornadu, torra a carrigare sa pàgina",
     "An error happened when trying to share your file" : "B'at àpidu un'errore proende a cumpartzire s'archìviu",
