@@ -10,9 +10,11 @@ OC.L10N.register(
     "Invalid file provided" : "ไฟล์ที่ระบุไม่ถูกต้อง",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
+    "Description" : "รายละเอียด",
     "Dismiss notification" : "ปิดการแจ้งเตือน",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
+    "Notification" : "การแจ้งเตือน",
     "Open settings" : "เปิดการตั้งค่า",
     "error" : "ข้อผิดพลาด",
     "Federation" : "ที่ติดต่อกับภายนอก",
@@ -24,7 +26,6 @@ OC.L10N.register(
     "Enabled" : "เปิดใช้งาน",
     "Disabled" : "ปิดใช้งาน",
     "Name" : "ชื่อ",
-    "Description" : "รายละเอียด",
     "All messages" : "ข้อความทั้งหมด",
     "@-mentions only" : "เฉพาะการกล่าวถึงแบบ @",
     "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
@@ -92,6 +93,7 @@ OC.L10N.register(
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Search" : "ค้นหา",
     "Grid view" : "มุมมองแบบตาราง",
+    "Keep" : "เก็บ",
     "Submit" : "ส่ง",
     "User" : "ผู้ใช้",
     "Password" : "รหัสผ่าน",
@@ -113,8 +115,6 @@ OC.L10N.register(
     "__language_name__" : "ไทย",
     "Tasks" : "งาน",
     "Notes" : "โน้ต",
-    "Loading" : "กำลังโหลด",
-    "Close" : "ปิด",
-    "Password protect" : "ป้องกันด้วยรหัสผ่าน"
+    "Close" : "ปิด"
 },
 "nplurals=1; plural=0;");
