@@ -164,6 +164,9 @@ OC.L10N.register(
     "Dismiss notification" : "Bỏ qua thông báo ",
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
+    "New message" : "Tin nhắn mới",
+    "Reminder" : "Lịch nhắc hẹn",
+    "Notification" : "Thông báo",
     "{user} in {call}" : "{user} trong {call}",
     "Deleted user in {call}" : "Người dùng đã xóa trong {call}",
     "{guest} (guest) in {call}" : "{guest} (khách) trong {call}",
@@ -341,7 +344,6 @@ OC.L10N.register(
     "Cancel" : "Hủy",
     "Add participant \"{user}\"" : "Thêm người tham gia \"{user}\"",
     "Loading …" : "Đang tải …",
-    "No upcoming events" : "Không có sự kiện sắp diễn ra ",
     "From" : "Từ",
     "To" : "Tới",
     "Calendar" : "Lịch",
@@ -393,9 +395,9 @@ OC.L10N.register(
     "Choose" : "Chọn",
     "The file must be a PNG or JPG" : "Tệp phải là PNG hoặc JPG",
     "Restricted" : "Bị giới hạn",
+    "Meeting" : "Cuộc họp",
     "Conversation settings" : "Cài đặt cuộc trò chuyện",
     "Personal" : "Cá nhân",
-    "Meeting" : "Cuộc họp",
     "Danger zone" : "Khu vực nguy hiểm",
     "Do you really want to delete \"{displayName}\"?" : "Bạn có thực sự muốn xóa \"{displayName}\" không?",
     "Error while deleting conversation" : "Lỗi khi xóa cuộc trò chuyện",
@@ -409,8 +411,6 @@ OC.L10N.register(
     "Save password" : "Lưu mật khẩu",
     "Resend invitations" : "Gửi lại lời mời",
     "Error occurred when opening or limiting the conversation" : "Đã xảy ra lỗi khi mở hoặc giới hạn cuộc trò chuyện",
-    "Error occurred when restricting the conversation to moderator" : "Đã xảy ra lỗi khi giới hạn cuộc trò chuyện với người kiểm duyệt",
-    "Error occurred when opening the conversation to everyone" : "Đã xảy ra lỗi khi mở cuộc trò chuyện với mọi người",
     "Start time has been updated" : "Thời gian bắt đầu đã được cập nhật",
     "Error occurred while updating start time" : "Đã xảy ra lỗi khi cập nhật thời gian bắt đầu",
     "Meeting start time" : "Thời gian bắt đầu cuộc họp",
@@ -437,6 +437,7 @@ OC.L10N.register(
     "SIP dial-in is now disabled" : "Tính năng quay số SIP hiện đã bị tắt",
     "Error occurred when enabling SIP dial-in" : "Đã xảy ra lỗi khi bật quay số SIP",
     "Error occurred when disabling SIP dial-in" : "Đã xảy ra lỗi khi tắt quay số SIP",
+    "Join" : "Tham gia",
     "Error while creating the conversation" : "Lỗi khi tạo cuộc trò chuyện",
     "Create conversation" : "Tạo cuộc trò chuyện",
     "Log in" : "Đăng nhập",
@@ -449,6 +450,7 @@ OC.L10N.register(
     "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
     "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
     "Conversation list" : "Danh sách cuộc trò chuyện",
+    "Unread messages" : "Tin nhắn chưa đọc",
     "Clear filter" : "Xóa bộ lọc",
     "Talk settings" : "Cài đặt Talk",
     "Users" : "Người dùng",
@@ -465,6 +467,11 @@ OC.L10N.register(
     "No camera available" : "Không có camera khả dụng",
     "No audio" : "Không có âm thanh",
     "No camera" : "Không có máy ảnh",
+    "Calls are not supported in your browser" : "Cuộc gọi không được hỗ trợ trong trình duyệt của bạn",
+    "Access to microphone is only possible with HTTPS" : "Chỉ có thể truy cập vào micrô với HTTPS",
+    "Access to microphone was denied" : "Quyền truy cập vào micrô đã bị từ chối",
+    "Error while accessing microphone" : "Lỗi khi truy cập micrô",
+    "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
     "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Upload" : "Tải lên",
     "Files" : "Tệp",
@@ -475,7 +482,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
     "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
     "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
-    "Unread messages" : "Tin nhắn chưa đọc",
     "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
     "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
@@ -513,7 +519,6 @@ OC.L10N.register(
     "Add more files" : "Thêm nhiều tập tin",
     "Send" : "Gửi",
     "Settings" : "Thiết lập",
-    "Join" : "Tham gia",
     "Disable lobby" : "Vô hiệu hóa sảnh đợi",
     "Settings for participant \"{user}\"" : "Cài đặt cho người tham gia \"{user}\"",
     "Participant \"{user}\"" : "Người tham gia \"{user}\"",
@@ -549,16 +554,10 @@ OC.L10N.register(
     "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
     "Select conversation" : "Chọn cuộc trò chuyện",
     "Edit display name" : "Chỉnh sửa tên hiển thị",
-    "Calls are not supported in your browser" : "Cuộc gọi không được hỗ trợ trong trình duyệt của bạn",
-    "Access to microphone is only possible with HTTPS" : "Chỉ có thể truy cập vào micrô với HTTPS",
-    "Access to microphone was denied" : "Quyền truy cập vào micrô đã bị từ chối",
-    "Error while accessing microphone" : "Lỗi khi truy cập micrô",
-    "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
     "Error while setting attachment folder" : "Lỗi khi cấu hình thư mục tệp đính kèm",
     "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
     "Error while setting read status privacy" : "Lỗi khi đặt quyền riêng tư của trạng thái đã đọc",
     "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
-    "Choose devices" : "Chọn thiết bị",
     "Attachments folder" : "Thư mục đính kèm",
     "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
     "Appearance" : "Ngoại hình",
@@ -607,6 +606,7 @@ OC.L10N.register(
     "Raise hand" : "Giơ tay",
     "Lower hand" : "Đặt tay xuống",
     "Mute others" : "Tắt tiếng người khác",
+    "Keep" : "Giữ",
     "Select a region" : "Chọn một khu vực",
     "Submit" : "Gửi đi",
     "Message without mention" : "Tin nhắn không đề cập",
@@ -664,8 +664,15 @@ OC.L10N.register(
     "Show all files" : "Hiện tất cả tệp",
     "Group" : "Nhóm",
     "You: {lastMessage}" : "Bạn: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
+    "Leave this page" : "Rời khỏi trang này",
+    "Join here" : "Tham gia tại đây",
+    "Post to a conversation" : "Đăng lên một cuộc trò chuyện",
+    "Post to conversation" : "Đăng lên cuộc trò chuyện",
     "Error occurred while allowing guests" : "Đã xảy ra lỗi khi cho phép khách",
     "Error occurred while disallowing guests" : "Đã xảy ra lỗi khi không cho phép khách",
+    "Error occurred when restricting the conversation to moderator" : "Đã xảy ra lỗi khi giới hạn cuộc trò chuyện với người kiểm duyệt",
+    "Error occurred when opening the conversation to everyone" : "Đã xảy ra lỗi khi mở cuộc trò chuyện với mọi người",
     "Conversation password has been saved" : "Mật khẩu cuộc trò chuyện đã được lưu",
     "Conversation password has been removed" : "Mật khẩu cuộc trò chuyện đã bị xóa",
     "Error occurred while saving conversation password" : "Đã xảy ra lỗi khi lưu mật khẩu cuộc trò chuyện",
@@ -677,9 +684,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Không thể gửi lời mời đến {actorId}",
     "Invitations sent" : "Lời mời đã được gửi",
     "Error occurred when sending invitations" : "Đã xảy ra lỗi khi gửi lời mời",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
-    "Leave this page" : "Rời khỏi trang này",
-    "Join here" : "Tham gia tại đây",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Trình duyệt bạn đang sử dụng không được vWorkspace Talk hỗ trợ đầy đủ. Vui lòng sử dụng phiên bản mới nhất của Mozilla Firefox, Microsoft Edge, Google Chrome, Opera hoặc Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Mất kết nối với máy chủ báo hiệu. Đang cố gắng kết nối lại.",
     "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
@@ -717,6 +721,7 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
     "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
     "Close" : "Đóng",
+    "Choose devices" : "Chọn thiết bị",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
     "Nextcloud Talk was updated, please reload the page" : "vWorkspace Talk đã được cập nhật, vui lòng tải lại trang",
     "Failed to join the conversation. Try to reload the page." : "Không tham gia được cuộc trò chuyện. Hãy thử tải lại trang.",
