@@ -305,25 +305,29 @@ class Config {
 			$urls[] = $this->getWebSocketDomainForSignalingServer($server['server']);
 		}
 
-		return $urls;
+		return array_filter($urls);
 	}
 
 	protected function getWebSocketDomainForSignalingServer(string $url): string {
+		if (str_ends_with($url, ':') || str_ends_with($url, ':/') || str_ends_with($url, '://')) {
+			return '';
+		}
+
 		$url .= '/';
 		if (str_starts_with($url, 'https://')) {
-			return 'wss://' . substr($url, 8, strpos($url, '/', 9) - 8);
+			return 'wss://' . substr($url, 8, strpos($url, '/', 8) - 8);
 		}
 
 		if (str_starts_with($url, 'http://')) {
-			return 'ws://' . substr($url, 7, strpos($url, '/', 8) - 7);
+			return 'ws://' . substr($url, 7, strpos($url, '/', 7) - 7);
 		}
 
 		if (str_starts_with($url, 'wss://')) {
-			return substr($url, 0, strpos($url, '/', 7));
+			return substr($url, 0, strpos($url, '/', 6));
 		}
 
 		if (str_starts_with($url, 'ws://')) {
-			return substr($url, 0, strpos($url, '/', 6));
+			return substr($url, 0, strpos($url, '/', 5));
 		}
 
 		$protocol = strpos($url, '://');
@@ -578,6 +582,38 @@ class Config {
 		return $this->config->getAppValue('spreed', 'signaling_token_pubkey_' . strtolower($alg));
 	}
 
+	public function deriveSignalingTokenPublicKey(string $privateKey, string $alg): string {
+		if (str_starts_with($alg, 'ES') || str_starts_with($alg, 'RS')) {
+			$opensslPrivateKey = openssl_pkey_get_private($privateKey);
+			$this->throwOnOpensslError();
+
+			$pubKey = openssl_pkey_get_details($opensslPrivateKey);
+			$this->throwOnOpensslError();
+
+			$public = $pubKey['key'];
+			if (!openssl_pkey_export($privateKey, $secret)) {
+				throw new \Exception('Could not export private key');
+			}
+		} elseif ($alg === 'EdDSA') {
+			$public = base64_encode(sodium_crypto_sign_publickey_from_secretkey($privateKey));
+		} else {
+			throw new \Exception('Unsupported algorithm ' . $alg);
+		}
+
+		return $public;
+	}
+
+	private function throwOnOpensslError() {
+		$errors = [];
+		while ($error = openssl_error_string()) {
+			$errors[] = $error;
+		}
+
+		if (!empty($errors)) {
+			throw new \Exception("OpenSSL error:\n" . implode("\n", $errors));
+		}
+	}
+
 	/**
 	 * @param IUser $user
 	 * @return array
