@@ -145,6 +145,8 @@ class RoomFormatter {
 			'recordingConsent' => $this->talkConfig->recordingConsentRequired() === RecordingService::CONSENT_REQUIRED_OPTIONAL ? $room->getRecordingConsent() : $this->talkConfig->recordingConsentRequired(),
 			'mentionPermissions' => Room::MENTION_PERMISSIONS_EVERYONE,
 			'isArchived' => false,
+			'isImportant' => false,
+			'isSensitive' => false,
 		];
 
 		if ($room->isFederatedConversation()) {
@@ -229,6 +231,8 @@ class RoomFormatter {
 			'breakoutRoomStatus' => $room->getBreakoutRoomStatus(),
 			'mentionPermissions' => $room->getMentionPermissions(),
 			'isArchived' => $attendee->isArchived(),
+			'isImportant' => $attendee->isImportant(),
+			'isSensitive' => $attendee->isSensitive(),
 		]);
 
 		if ($room->isFederatedConversation()) {
@@ -389,6 +393,7 @@ class RoomFormatter {
 			}
 		}
 
+		$skipLastMessage = $skipLastMessage || $attendee->isSensitive();
 		$lastMessage = $skipLastMessage ? null : $room->getLastMessage();
 		if (!$room->isFederatedConversation() && $lastMessage instanceof IComment) {
 			$lastMessageData = $this->formatLastMessage(
