@@ -25,6 +25,7 @@ use OCP\IUser;
 use OCP\IUserSession;
 use OCP\L10N\IFactory;
 use OCP\Settings\ISettings;
+use OCP\Support\Subscription\IRegistry;
 use OCP\Util;
 
 class AdminSettings implements ISettings {
@@ -38,6 +39,7 @@ class AdminSettings implements ISettings {
 		private ICacheFactory $memcacheFactory,
 		private IGroupManager $groupManager,
 		private MatterbridgeManager $bridgeManager,
+		private IRegistry $subscription,
 		IUserSession $userSession,
 		private IL10N $l10n,
 		private IFactory $l10nFactory,
@@ -126,6 +128,7 @@ class AdminSettings implements ISettings {
 	}
 
 	protected function initSignalingServers(): void {
+		$this->initialState->provideInitialState('has_valid_subscription', $this->subscription->delegateHasValidSubscription());
 		$this->initialState->provideInitialState('has_cache_configured', $this->memcacheFactory->isAvailable());
 		$this->initialState->provideInitialState('signaling_mode', $this->talkConfig->getSignalingMode(false));
 		$this->initialState->provideInitialState('signaling_servers', [
@@ -280,7 +283,7 @@ class AdminSettings implements ISettings {
 			['code' => 'MF', 'name' => $this->l10n->t('Saint Martin (French part)')],
 			['code' => 'MG', 'name' => $this->l10n->t('Madagascar')],
 			['code' => 'MH', 'name' => $this->l10n->t('Marshall Islands')],
-			['code' => 'MK', 'name' => $this->l10n->t('Macedonia, the former Yugoslav Republic of')],
+			['code' => 'MK', 'name' => $this->l10n->t('North Macedonia')],
 			['code' => 'ML', 'name' => $this->l10n->t('Mali')],
 			['code' => 'MM', 'name' => $this->l10n->t('Myanmar')],
 			['code' => 'MN', 'name' => $this->l10n->t('Mongolia')],
@@ -448,6 +451,8 @@ class AdminSettings implements ISettings {
 			'uploadLimit' => is_infinite($uploadLimit) ? 0 : $uploadLimit,
 		]);
 		$this->initialState->provideInitialState('recording_consent', $this->talkConfig->getRecordingConsentConfig());
+		$this->initialState->provideInitialState('call_recording_transcription', $this->serverConfig->getAppValue('spreed', 'call_recording_transcription', 'no') === 'yes');
+		$this->initialState->provideInitialState('call_recording_summary', $this->serverConfig->getAppValue('spreed', 'call_recording_summary', 'yes') === 'yes');
 	}
 
 	protected function initSIPBridge(): void {
